import { FocusAwareStatusBar, SafeAreaView, ScrollView, View,  } from '@/components/ui'
import * as React from 'react'
import { Keyboard , TouchableWithoutFeedback } from 'react-native'
import PrimeButton from '@/library/prime-button';
import PrimeLabel from '@/library/prime-label';
import PrimeSocialButton from '@/library/prime-social-button';
import PrimeTextInput from '@/library/prime-textinput';



const IconDummyComponent = () => {
  return <View className='w-6 h-6 bg-red-500 rounded-full'/>
}
const IconDummyComponent2 = () => {
  return <View className='w-6 h-6 bg-blue-500 rounded-full'/>
}


export default function Paper () {
  const [text, setText] = React.useState('');
  const [passwordText, setPasswordText] = React.useState('');
  const [passwordVisible, setPasswordVisible] = React.useState(true);
  const [countText, setCountText] = React.useState('');

  interface IdState {
    first: string;
    second: string;
  }

  const [idValue, setIdValue] = React.useState<IdState>({
    first: '',
    second: ''
  });

  const handleIdChange = {
    onFirstChange: (text: string) => {
      setIdValue(prev => ({
        ...prev,
        first: text
      }));
    },
    onSecondChange: (text: string) => {
      setIdValue(prev => ({
        ...prev,
        second: text
      }));
    }
  };

  const handleClear = () => {
    setIdValue({
      first: '',
      second: ''
    });
  };


  const handleCustomValidation = (text: string) => {
    if (text.length <= 10 && /^[a-zA-Z]*$/.test(text)) { // 예: 10자 이하, 알파벳만 허용
      setCountText(text);
    }
  }

  return (
    <>
        <FocusAwareStatusBar />
          <SafeAreaView className="flex-1 px-6 pt-16 bg-white">
            <TouchableWithoutFeedback onPress={Keyboard.dismiss}>
              <View className="flex-1 justify-center items-center gap-4">

              {/* 정적 라벨 */}
              <PrimeLabel value={"라벨 텍스트"} labelClassName="text-sm" isLabelOnly required />

              {/* 카운팅 라벨 */}
              <PrimeLabel value={countText} onChangeText={handleCustomValidation} labelClassName="text-lg" charactorCount={true} maxCharactorCount={10} />


              <PrimeTextInput 
                label={{
                  text: '주민등록번호',
                  style: { fontSize: 14 },
                  required: true 
                }}
                input={{
                  mode: 'id',
                  idValue: idValue,
                  onIdChange: {
                    onFirstChange: handleIdChange.onFirstChange,
                    onSecondChange: handleIdChange.onSecondChange
                  },
                  border: 'border-2 border-gray-700'
                }}
                status="none"
                statusConfig={{
                  message: "에러"
                }}
                onClear={handleClear}
              />

              <PrimeTextInput 
                label={{
                  text: '일반',
                  style: { fontSize: 14 }
                }}
                input={{
                  mode: 'default',
                  value: text,
                  placeholder: '홍길동',
                }}
                status="none"
                statusConfig={{
                  message: "에러"
                }}
                onClear={() => setText('')}
                onChangeText={setText}
              />


              <PrimeTextInput 
                label={{
                  text: '패스워드'
                }}
                input={{
                  mode: 'password',
                  value: passwordText,
                  placeholder: '패스워드',
                  // border: 'border-2 border-gray-700',
                  isSecureTextEntry: passwordVisible,
                  onSecureTextEntryChange: setPasswordVisible
                }}
                status="error"
                statusConfig={{
                  message: "에러힌트"
                }}
                onChangeText={setPasswordText}
                onClear={() => setPasswordText('')}
              />



              <PrimeButton 
                // disabled={true}
                // loading={true}
                variant='primaryLow'
                text={'테스트'}
                shape={'round'}
                // backgroundColor={'brand-primary-default'}
                // textColor={'blue'}
                onPress={() => console.log('테스트')}
              />



            <PrimeSocialButton
              type="google"
              onPress={() => console.log('카카오 로그인')}
            />
            </View>
        </TouchableWithoutFeedback>
      </SafeAreaView>
    </>
  );
}
